@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 #
 # Copyright (c) 2012-2015 Dropmysite.com <https://dropmyemail.com>
 # Copyright (c) 2015 Webhippie <http://www.webhippie.de>
@@ -23,17 +25,5 @@
 #
 
 class PoToJson
-  class Version
-    MAJOR = 2
-    MINOR = 0
-    PATCH = 0
-
-    PRE = nil
-
-    class << self
-      def to_s
-        [MAJOR, MINOR, PATCH, PRE].compact.join(".")
-      end
-    end
-  end
+  VERSION = "2.1.2".freeze
 end
